Installation
============

.. code-block:: bash

    pip install pygrappa

Usage
=====

See the `examples` module.

About
=====

GRAPPA is a popular parallel imaging reconstruction algorithm.
Unfortunately there aren't a lot of easy to use Python implementations
available, so I decided to release this simple one.
